@@ -18,20 +18,42 @@ has 'tmpdir' => (
 
 sub dir_file {
     my $self = shift;
-
-    return File::Spec->catfile($self->tmpdir, $self->confname);
+    my $dirs = (File::Spec->splitpath( $self->tmpdir, 1 ))[1];
+    return File::Spec->catfile($dirs, $self->confname);
 }
 
 sub user_file {
     my $self = shift;
 
-    return File::Spec->catfile($self->tmpdir, 'home', $self->confname);
+    return File::Spec->catfile(
+        ( File::Spec->splitpath( $self->tmpdir, 1 ) )[1],
+        'home', $self->confname );
 }
 
 sub global_file {
     my $self = shift;
 
-    return File::Spec->catfile($self->tmpdir, 'etc', $self->confname);
+    return File::Spec->catfile(
+        ( File::Spec->splitpath( $self->tmpdir, 1 ) )[1],
+        'etc', $self->confname );
+}
+
+sub slurp {
+    my $self = shift;
+    my $file = shift || $self->dir_file;
+    local ($/);
+    open( my $fh, $file ) or die "Unable to open file $file: $!";
+    return <$fh>;
+}
+
+sub burp {
+    my $self = shift;
+    my $content = pop;
+    my $file_name = shift || $self->dir_file;
+
+    open( my $fh, ">", $file_name )
+        || die "can't open $file_name: $!";
+    print $fh $content;
 }
 
 __PACKAGE__->meta->make_immutable;
